@@ -165,8 +165,11 @@ class Game(object):
         def fset(self, value):
             # pylint: disable=W0212
             if self.__winner != value:
+                if self.__winner:
+                    self.__winner.invalidateHand()
                 self.__winner = value
-                value.invalidateHand()
+                if value:
+                    value.invalidateHand()
         return property(**locals())
 
     def addCsvTag(self, tag, forAllPlayers=False):
@@ -671,6 +674,7 @@ class Game(object):
         else:
             game.eastMJCount = 0
         game.handctr += 1
+        game.notRotated += 1
         game.maybeRotateWinds()
         game.sortPlayers()
         game.wall.decorate()
